import requests
from requests.packages import urllib3


def set_upload_document(id, path, link_upload_document, headers_upload):
    urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

    post_url = link_upload_document
    is_success = 0
    count = 0
    while count < 3 or is_success == 0:
        print("uploading file : ", path)
        files = {'RemoteFile': open(path, 'rb')}
        payload = {
            "id": id
        }
        resp = requests.post(post_url, headers=headers_upload, files=files,
                             data=payload, verify=False)
        print(resp.content)
        is_success = resp.status_code

        if is_success == 200:
            print(path, ": success to upload")
            break
        else:
            print(path, ": FAIL.... to upload")
            print("trying upload again... attemp for ", count + 1, " times")
            count += 1

        # print("====================================")
        # print("respon uploaded adalah", resp.content)



import os
import pandas as pd

# Set the path to the folder containing the Excel files
folder_path = '/path/to/folder'

# Create an empty DataFrame to store the combined data
combined_data = pd.DataFrame()
# Loop through all the Excel files in the folder
for file_name in os.listdir(folder_path):
    if file_name.endswith('.xlsx'):  # Check if the file is an Excel file
        file_path = os.path.join(folder_path, file_name)
        data = pd.read_excel(file_path)
        combined_data = combined_data.append(data)

# Save the combined data to a new Excel file
combined_data.to_excel('combined_data.xlsx', index=False)



import requests
import time


def get_json_response(url, headers=None):
    retries = 3  # maximum number of retries
    for i in range(retries):
        try:
            response = requests.get(url, headers=headers, verify=False)
            response.raise_for_status()  # raise an error if the status code is not 2xx
            return response.json()  # return the JSON response data
        except ConnectionError:
            # handle connection error here
            print('Connection error')
        except requests.exceptions.HTTPError as http_err:
            # handle HTTP error here
            print(f'HTTP error occurred: {http_err}')
            return None
        except Exception as err:
            # handle other errors here
            print(f'Other error occurred: {err}')
        if i < retries - 1:
            print(f'Retrying ({i + 1}/{retries})...')
            time.sleep(2 ** i)
    return None


def get_json_response(url, headers=None, params=None):
    retries = 3  # maximum number of retries
    for i in range(retries):
        try:
            response = requests.get(
                url, headers=headers, params=params, verify=False)
            response.raise_for_status()  # raise an error if the status code is not 2xx
            return response.json()  # return the JSON response data
        except ConnectionError:
            # handle connection error here
            print('Connection error')
        except requests.exceptions.HTTPError as http_err:
            # handle HTTP error here
            print(f'HTTP error occurred: {http_err}')
            return None
        except Exception as err:
            # handle other errors here
            print(f'Other error occurred: {err}')
        if i < retries - 1:
            print(f'Retrying ({i + 1}/{retries})...')
            time.sleep(2 ** i)
    return None


def set_json_response(url, headers=None, payload=None, verify=False):
    retries = 3  # maximum number of retries
    for i in range(retries):
        try:
            response = requests.get(url, headers=headers)
            response.raise_for_status()  # raise an error if the status code is not 2xx
            return response.json()  # return the JSON response data
        except ConnectionError:
            # handle connection error here
            print('Connection error')
        except requests.exceptions.HTTPError as http_err:
            # handle HTTP error here
            print(f'HTTP error occurred: {http_err}')
            return None
        except Exception as err:
            # handle other errors here
            print(f'Other error occurred: {err}')
        if i < retries - 1:
            print(f'Retrying ({i + 1}/{retries})...')
            time.sleep(2 ** i)
    return None



import re
import os
text = "The quick brown fox jumps over the lazy dog"
list_jenis_dokument = [
    {
        "new": "",
        "old": "Ijazah"
    }
]


def to_text(list, path):
    with open(path, 'w') as f:
        f.write('\n'.join(list))
    print("done file at the", path)


path_write = "C:\\Users\\Rifo\\Desktop\\output2.txt"
path_directory = "c:\\dmsUploadExperiment\\"

list_folder = os.listdir(path_directory)
list_files = []
for folder in list_folder:
    path_folder = os.path.join(path_directory + folder)
    list_document = os.listdir(path_directory + folder)

    for document in list_document:
        doc = 1
        for keyval in list_jenis_dokument:
            name = keyval["name"]

            if (re.search(name.lower(), document.lower())):
                print(name.lower() + "-" + document.lower())
                doc = 0
        if doc == 1:
            list_files.append(os.path.join(
                path_directory + folder + "\\" + document))
to_text(list_files, path_write)
